@@ -14,15 +14,17 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import os
 import sys
-from sid_func import client_sid
-from function import get_sid, get_ip_mac_type
-from create_cert import (generateRSAKey, makePKey,
+from .sid_func import client_sid
+from .function import get_sid, get_ip_mac_type
+from .create_cert import (generateRSAKey, makePKey,
                          makeRequest, passphrase_callback)
 import hashlib
-from client_class import HTTPSClientCertTransport
-from cert_verify import VerifyError
+from .client_class import HTTPSClientCertTransport
+from .cert_verify import VerifyError
 from calculate.core.datavars import DataVarsCore
 from calculate.lib.utils.files import readFile
 
@@ -40,19 +42,19 @@ def client_post_cert(client):
     results = client.service.post_cert()
 
     if results[0][0] == -4:
-        print _("Certificate not found in the server database!")
+        print(_("Certificate not found in the server database!"))
         sys.exit(1)
     client_sid(sid, client, cert_id=results[0][0])
     if results[0][0] == -3:
-        print _("Certificate not sent!")
+        print(_("Certificate not sent!"))
     else:
-        print _(" Your certifitate ID = %d") % (results[0][0])
+        print(_(" Your certifitate ID = %d") % (results[0][0]))
         try:
             if results[0][1] == -2:
-                print _("Certificate expired")
+                print(_("Certificate expired"))
             elif results[0][1] > 0:
-                print _("The certificate expires after %d days") % (
-                    results[0][1])
+                print(_("The certificate expires after %d days") % (
+                    results[0][1]))
         except (IndexError, AttributeError):
             pass
 
@@ -84,8 +86,8 @@ def delete_old_cert(client):
 
 def client_post_request(cert_path, by_host):
     if os.path.exists(cert_path + 'req_id'):
-        print _("You already sent a certificate signature request.")
-        print _("Request ID = %s") % readFile(cert_path + 'req_id')
+        print(_("You already sent a certificate signature request."))
+        print(_("Request ID = %s") % readFile(cert_path + 'req_id'))
         ans = raw_input(_("Send a new request? y/[n]: "))
         if not ans.lower() in ['y', 'yes']:
             return 0
@@ -94,10 +96,10 @@ def client_post_request(cert_path, by_host):
     try:
         port = int(port)
     except ValueError:
-        print _('The port number must be int')
+        print(_('The port number must be int'))
         return 1
     url = "https://%s:%d/?wsdl" % (by_host, port)
-    print url + '\n' + _("connecting...")
+    print(url + '\n' + _("connecting..."))
     from suds.client import Client
     # try:
     client = Client(url, transport=HTTPSClientCertTransport(None, None,
@@ -112,7 +114,7 @@ def client_post_request(cert_path, by_host):
     key = cert_path + server_host_name + '.key'
     csr_file = cert_path + server_host_name + '.csr'
     if os.path.exists(key) and os.path.exists(csr_file):
-        print _("the private key and request now exist")
+        print(_("the private key and request now exist"))
         ask = raw_input(_("Create a new private key and request? y/[n]: "))
         if ask.lower() in ['y', 'yes']:
             new_key_req(key, cert_path, server_host_name)
@@ -124,33 +126,33 @@ def client_post_request(cert_path, by_host):
     res = client.service.post_client_request(request=data, ip=ip,
                                              mac=mac, client_type=client_type)
     if int(res) < 0:
-        print _("This server is not enabled to sign certificates!")
+        print(_("This server is not enabled to sign certificates!"))
         return 1
     fc = open(cert_path + 'req_id', 'w')
     fc.write(res)
     fc.close()
-    print _("Your request ID = %s") % res
+    print(_("Your request ID = %s") % res)
     return 0
 
 
 def client_get_cert(cert_path, args):
     if not os.path.exists(cert_path + 'req_id'):
-        print _("request not sent or file %s deleted") % (cert_path + 'req_id')
+        print(_("request not sent or file %s deleted") % (cert_path + 'req_id'))
         return 1
     fc = open(cert_path + 'req_id', 'r')
     req_id = fc.read()
     fc.close()
 
-    print '\n' + _("the URL looks like"), "https://%s:[port]/?wsdl" \
-                                          % args.from_host
+    print('\n' + _("the URL looks like"), "https://%s:[port]/?wsdl" \
+                                          % args.from_host)
     port = raw_input(_("Enter the port number: "))
     try:
         port = int(port)
     except ValueError:
-        print _('The port number must be int')
+        print(_('The port number must be int'))
         return 1
     url = "https://%s:%d/?wsdl" % (args.from_host, port)
-    print url + '\n' + _("connecting...")
+    print(url + '\n' + _("connecting..."))
 
     from suds.client import Client
 
@@ -158,14 +160,14 @@ def client_get_cert(cert_path, args):
         client = Client(url, transport=HTTPSClientCertTransport(None, None,
                                                                 cert_path))
     except KeyboardInterrupt:
-        print '\n' + _("Closed. Connection error.")
+        print('\n' + _("Closed. Connection error."))
         return 1
 
     server_host_name = client.service.get_server_host_name()
 
     if not os.path.exists(cert_path + server_host_name + '.csr'):
-        print _('Request %s not found') % (
-            cert_path + server_host_name + '.csr')
+        print(_('Request %s not found') % (
+            cert_path + server_host_name + '.csr'))
         return 1
     request = readFile(cert_path + server_host_name + '.csr')
     md5 = hashlib.md5()
@@ -176,23 +178,23 @@ def client_get_cert(cert_path, args):
     cert = result[0][0]
     ca_root = result[0][1]
     if cert == '1':
-        print _('The signature request was rejected!')
+        print(_('The signature request was rejected!'))
         return 1
     elif cert == '2':
-        print _("The signature request has not been examined yet.")
-        print _("Your request ID = %s") % req_id
+        print(_("The signature request has not been examined yet."))
+        print(_("Your request ID = %s") % req_id)
         return 1
     elif cert == '3':
-        print _("The signature request does not match earlier data.")
+        print(_("The signature request does not match earlier data."))
         return 1
     elif cert == '4':
-        print _("The request was sent from another IP.")
+        print(_("The request was sent from another IP."))
         return 1
     fc = open(cert_path + server_host_name + '.crt', 'w')
     fc.write(cert)
     fc.close()
     os.unlink(cert_path + 'req_id')
-    print 'OK. Certificate saved. Your certificate ID = %s' % req_id
+    print('OK. Certificate saved. Your certificate ID = %s' % req_id)
 
     if ca_root:
         cl_vars = DataVarsCore()
@@ -241,7 +243,7 @@ def client_get_cert(cert_path, args):
             fc.close()
 
             if not filename:
-                print _('Field "CN" not found in the certificate!')
+                print(_('Field "CN" not found in the certificate!'))
                 return 1
 
             fd = open(cl_client_cert_dir + '/ca/' + filename, 'w')
@@ -253,9 +255,9 @@ def client_get_cert(cert_path, args):
             fa = open(user_root_cert, 'a')
             fa.write(ca_root)
             fa.close()
-            print _("Certificate added")
+            print(_("Certificate added"))
         else:
-            print _("file containing the CA certificate now exists")
+            print(_("file containing the CA certificate now exists"))
     return 0
 
 
@@ -267,14 +269,14 @@ def client_post_auth(client):
             pass  # client_post_cert(client)
         else:
             # client_post_request(client)
-            print _('You do not have a certificate. Use option '
+            print(_('You do not have a certificate. Use option '
                     '--gen-cert-by HOST to generate a new certificate '
                     'or --get-cert-from HOST to get the certificate '
-                    'from the server.')
+                    'from the server.'))
             sys.exit()
-        print client.service.versions(sid, VERSION)
-    except VerifyError, e:
-        print e.value
+        print(client.service.versions(sid, VERSION))
+    except VerifyError as e:
+        print(e.value)
         sys.exit()
 
 
@@ -282,18 +284,18 @@ def client_post_auth(client):
 def cert_right_inf(client, sid, cert_id):
     s = client.service.view_cert_right(cert_id)
     if s[0][0] == "-1":
-        print _("Certificate not found on the server!")
+        print(_("Certificate not found on the server!"))
         return -1
     if s[0][0] == "-2":
-        print _("Failed to create the certificate ID!")
+        print(_("Failed to create the certificate ID!"))
         return -2
     if s[0][0] == "Permission denied":
-        print _("%s: Permission denied") % s[0][1]
+        print(_("%s: Permission denied") % s[0][1])
         return -3
 
-    print _("The certificate with ID = %d can execute:") % cert_id
+    print(_("The certificate with ID = %d can execute:") % cert_id)
     for meth in s[0]:
-        print " - %s" % meth
+        print(" - %s" % meth)
 
 
 # Viewing rights of any certificate on server by its id
@@ -302,19 +304,19 @@ def client_view_cert_right(client):
     try:
         cert_id = int(cert_id)
     except ValueError:
-        print _("Invalid certificate ID")
+        print(_("Invalid certificate ID"))
         return 1
     try:
         sid = get_sid(client.SID_FILE)
         if cert_id > 0:
             cert_right_inf(client, sid, cert_id)
         else:
-            print _("Please enter a valid certificate ID!")
-    except Exception, e:
+            print(_("Please enter a valid certificate ID!"))
+    except Exception as e:
         if e[0][0] == 403:
-            print _('Permission denied')
+            print(_('Permission denied'))
         else:
-            print e
+            print(e)
         # print _("Failed to get data")
         return 1
     return 0
