@@ -22,7 +22,8 @@ import logging
 from calculate.console.application.client_class import Client_suds
 import os
 import sys
-import urllib2
+# import urllib2
+import urllib.request as urllib2
 from calculate.core.datavars import DataVarsCore
 from calculate.core.client.function import clear
 from calculate.consolegui.application.client_class import (
