@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
 import os
 import sys
 import calculate.contrib
@@ -44,8 +45,8 @@ def clear():
         try:
             os.unlink(filename)
         except OSError as e:
-            print str(e)
-            print _("Failed to clear the cache! ")
+            print(str(e))
+            print(_("Failed to clear the cache! "))
             return 1
 
 
