@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 from calculate.core.server.loaded_methods import LoadedMethods
 
 import calculate.contrib
@@ -671,7 +672,7 @@ class CoreWsdl(CoreServiceInterface):
         curThread = threading.currentThread()
         cert = curThread.client_cert
 
-        from cert_cmd import find_cert_id
+        from .cert_cmd import find_cert_id
 
         cert_id = find_cert_id(cert, cls.data_path, cls.certbase)
         cert_id = int(cert_id)
