@@ -26,9 +26,9 @@ setLocalTranslate('cl_core3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 from . import setup_package
-from . import server.certificate as certificate
-from . import server.groups as groups
-from . import server.request as request
+from .server import certificate as certificate
+from .server import groups as groups
+from .server import request as request
 from . import set_vars
 from .backup import Backup, BackupError
 from calculate.core.utils.cl_backup import ClBackupAction
